@@ -60,6 +60,9 @@ urlpatterns = patterns(
     url(r'^collage_popup/$',
         'lizard_map.views.collage_popup',
         name="lizard_map.collage_popup"),
+    url(r'^collage_empty/$',
+        'lizard_map.views.collage_empty',
+        name="lizard_map_collage_empty"),
     url(r'^snippet/(?P<snippet_id>\d+)/popup$',
         'lizard_map.views.snippet_popup',
         name="lizard_map.snippet_popup"),
